IL-2 FB Mission Parser
======================

|PyPi package| |PyPi downloads| |Docs| |License|

|Build Status| |Coverage Status| |Code Review| |Health| |Quality| |Requirements|


This is a library for parsing mission file of ``IL-2 Forgotten Battles``. It
produces detailed information about mission.

Please, `read the docs`_ to get full information about this project.

You can dig around `Wiki pages`_ also.

And you can see how it works live on `project's demo page`_.


.. |Build Status| image:: http://img.shields.io/travis/IL2HorusTeam/il2fb-mission-parser.svg?style=flat&branch=master
   :target: https://travis-ci.org/IL2HorusTeam/il2fb-mission-parser
.. |Coverage Status| image:: http://img.shields.io/coveralls/IL2HorusTeam/il2fb-mission-parser.svg?style=flat&branch=master
   :target: https://coveralls.io/r/IL2HorusTeam/il2fb-mission-parser?branch=master
.. |PyPi package| image:: http://img.shields.io/pypi/v/il2fb-mission-parser.svg?style=flat
   :target: http://badge.fury.io/py/il2fb-mission-parser/
.. |PyPi downloads| image:: http://img.shields.io/pypi/dm/il2fb-mission-parser.svg?style=flat
   :target: https://crate.io/packages/il2fb-mission-parser/
.. |Docs| image:: https://readthedocs.org/projects/il-2-missions-parser/badge/?version=latest&style=flat
   :target: `read the docs`_
.. |License| image:: https://img.shields.io/badge/license-LGPLv3-brightgreen.svg?style=flat
   :target: https://github.com/IL2HorusTeam/il2fb-mission-parser/blob/master/LICENSE
.. |Code Review| image:: https://www.codacy.com/project/badge/4c79f2cb39234620bce5d4c49a54be52
    :target: https://www.codacy.com/public/IL2HorusTeam/il2fbmissionparser/dashboard
    :alt: Codacy Code Review
.. |Health| image:: https://landscape.io/github/IL2HorusTeam/il2fb-mission-parser/master/landscape.png?style=flat
   :target: https://landscape.io/github/IL2HorusTeam/il2fb-mission-parser/master
   :alt: Code Health
.. |Quality| image:: https://scrutinizer-ci.com/g/IL2HorusTeam/il2fb-mission-parser/badges/quality-score.png?b=master&style=flat
   :target: https://scrutinizer-ci.com/g/IL2HorusTeam/il2fb-mission-parser/?branch=master
   :alt: Scrutinizer Code Quality
.. |Requirements| image:: https://requires.io/github/IL2HorusTeam/il2fb-mission-parser/requirements.svg?branch=master&style=flat
    :target: https://requires.io/github/IL2HorusTeam/il2fb-mission-parser/requirements/?branch=master
    :alt: Requirements Status


.. _read the docs: http://il-2-missions-parser.readthedocs.org/en/latest/
.. _Wiki pages: https://github.com/IL2HorusTeam/il2fb-mission-parser/wiki
.. _project's demo page: http://il2fb-mission-parser-demo.herokuapp.com/
